@@ -9,7 +9,9 @@ import numpy as n
 from math import degrees
 from six.moves import range
 from xfab import checks
-
+from xfab import CHECKS
+from xfab import xfab_logging
+logger = xfab_logging.get_module_level_logger(__name__)
 
 def find_omega_general(g_w, twoth, w_x, w_y):
     """
@@ -418,7 +420,7 @@ def ubi_to_u(ubi):
     unit_cell = ubi_to_cell(ubi)
     B = form_b_mat(unit_cell)
     U = n.transpose(n.dot(B, ubi))/(2*n.pi)
-    if checks.is_activated(): checks._check_rotation_matrix(U)
+    if CHECKS.activated: checks._check_rotation_matrix(U)
 
     return U
         
@@ -440,7 +442,7 @@ def ubi_to_u_and_eps(ubi,unit_cell):
     B_ubi = form_b_mat(unit_cell_ubi)
     U = n.transpose(n.dot(B_ubi, ubi))/(2*n.pi)
 
-    if checks.is_activated(): checks._check_rotation_matrix(U)
+    if CHECKS.activated: checks._check_rotation_matrix(U)
 
     eps = b_to_epsilon(B_ubi, unit_cell)
     
@@ -612,7 +614,7 @@ def euler_to_u(phi1, PHI, phi2):
     Origingal MATLAB code from: Henning Poulsen, Risoe 15/6 2002.
     
     """
-    if checks.is_activated(): checks._check_euler_angles(phi1, PHI, phi2)
+    if CHECKS.activated: checks._check_euler_angles(phi1, PHI, phi2)
 
     U = n.zeros((3, 3))
     U[0, 0] =   n.cos(phi1)*n.cos(phi2)-n.sin(phi1)*n.sin(phi2)*n.cos(PHI)
@@ -664,7 +666,7 @@ def u_to_euler(U):
 
         Last Modified: Axel Henningsson, January 2021
     """
-    if checks.is_activated(): checks._check_rotation_matrix(U)
+    if CHECKS.activated: checks._check_rotation_matrix(U)
 
     tol = 1e-8
     PHI = n.arccos(U[2, 2])
@@ -716,7 +718,7 @@ def u_to_rod(U):
 
     Function taken from GrainsSpotter by Soeren Schmidt
     """
-    if checks.is_activated(): checks._check_rotation_matrix(U)
+    if CHECKS.activated: checks._check_rotation_matrix(U)
 
     ttt = 1+U[0, 0]+U[1, 1]+U[2, 2]
     if abs(ttt) < 1e-16: 
@@ -734,7 +736,7 @@ def u_to_ubi(u_mat,unit_cell):
     OUTPUT: UBI 3x3 matrix
 
     """
-    if checks.is_activated(): checks._check_rotation_matrix(u_mat)
+    if CHECKS.activated: checks._check_rotation_matrix(u_mat)
 
     b_mat = form_b_mat(unit_cell)
     
@@ -817,7 +819,7 @@ def ub_to_u_b(UB):
         U[1, 2] = -U[1, 2]
         U[2, 2] = -U[2, 2]
 
-    if checks.is_activated(): checks._check_rotation_matrix(U)
+    if CHECKS.activated: checks._check_rotation_matrix(U)
 
     return (U, B)
 
@@ -1128,7 +1130,7 @@ def genhkl_base(unit_cell, sysconditions, sintlmin, sintlmax, crystal_system='tr
 
     # Triclinic : Laue group -1
     if Laue_class == '-1':
-        print('Laue class : -1', unit_cell)
+        logger.debug('Laue class : -1 %s'%unit_cell)
         segm = n.array([[[ 0, 0,  0], [ 1, 0, 0], [ 0, 1, 0], [ 0, 0,  1]],
                         [[-1, 0,  1], [-1, 0, 0], [ 0, 1, 0], [ 0, 0,  1]],
                         [[-1, 1,  0], [-1, 0, 0], [ 0, 1, 0], [ 0, 0, -1]],
@@ -1142,7 +1144,7 @@ def genhkl_base(unit_cell, sysconditions, sintlmin, sintlmax, crystal_system='tr
     # Monoclinic : Laue group 2/M 
     # unique b        
     if Laue_class == '2/m':
-        print('Laue class : 2/m', unit_cell)
+        logger.debug('Laue class : 2/m %s'%unit_cell)
         segm = n.array([[[ 0, 0,  0], [ 1, 0, 0], [ 0, 1, 0], [ 0, 0,  1]],
                         [[-1, 0,  1], [-1, 0, 0], [ 0, 1, 0], [ 0, 0,  1]]])
 
@@ -1177,31 +1179,31 @@ def genhkl_base(unit_cell, sysconditions, sintlmin, sintlmax, crystal_system='tr
 
     # Laue group : -3M1
     if Laue_class == '-3m1':
-        print('Laue class : -3m1 (hex)', unit_cell)
+        logger.debug('Laue class : -3m1 (hex) %s'%unit_cell)
         if unit_cell[4]==unit_cell[5]:
-            print('#############################################################')
-            print('# Are you using a rhombohedral cell in a hexagonal setting? #')
-            print('#############################################################')
+            logger.debug('#############################################################')
+            logger.debug('# Are you using a rhombohedral cell in a hexagonal setting? #')
+            logger.debug('#############################################################')
         segm = n.array([[[ 0, 0,  0], [ 1, 0, 0], [ 1, 1, 0], [ 0, 0,  1]],
                         [[ 0, 1,  1], [ 0, 1, 0], [ 1, 1, 0], [ 0, 0,  1]]])
 
     # Laue group : -31M
     if Laue_class == '-31m':
-        print('Laue class : -31m (hex)', unit_cell)
+        logger.debug('Laue class : -31m (hex) %s'%unit_cell)
         if unit_cell[4]==unit_cell[5]:
-            print('#############################################################')
-            print('# Are you using a rhombohedral cell in a hexagonal setting? #')
-            print('#############################################################')
+            logger.debug('#############################################################')
+            logger.debug('# Are you using a rhombohedral cell in a hexagonal setting? #')
+            logger.debug('#############################################################')
         segm = n.array([[[ 0, 0,  0], [ 1, 0, 0], [ 1, 1, 0], [ 0, 0,  1]],
                         [[ 1, 1, -1], [ 1, 0, 0], [ 1, 1, 0], [ 0, 0, -1]]])
 
     # Laue group : -3
     if Laue_class == '-3' and cell_choice!='rhombohedral':
-        print('Laue class : -3 (hex)', unit_cell)
+        logger.debug('Laue class : -3 (hex) %s'%unit_cell)
         if unit_cell[4]==unit_cell[5]:
-            print('#############################################################')
-            print('# Are you using a rhombohedral cell in a hexagonal setting? #')
-            print('#############################################################')
+            logger.debug('#############################################################')
+            logger.debug('# Are you using a rhombohedral cell in a hexagonal setting? #')
+            logger.debug('#############################################################')
         segm = n.array([[[ 0, 0,  0], [ 1, 0, 0], [ 1, 1, 0], [ 0, 0,  1]],
                         [[ 1, 2,  0], [ 1, 1, 0], [ 0, 1, 0], [ 0, 0,  1]],
                         [[ 0, 1,  1], [ 0, 1, 0], [-1, 1, 0], [ 0, 0,  1]]])
@@ -1209,21 +1211,21 @@ def genhkl_base(unit_cell, sysconditions, sintlmin, sintlmax, crystal_system='tr
     # RHOMBOHEDRAL
     # Laue group : -3M
     if Laue_class == '-3m' and cell_choice=='rhombohedral':
-        print('Laue class : -3m (Rhom)', unit_cell)
+        logger.debug('Laue class : -3m (Rhom) %s'%unit_cell)
         if unit_cell[4]!=unit_cell[5]:
-            print('#############################################################')
-            print('# Are you using a hexagonal cell in a rhombohedral setting? #')
-            print('#############################################################')
+            logger.debug('#############################################################')
+            logger.debug('# Are you using a hexagonal cell in a rhombohedral setting? #')
+            logger.debug('#############################################################')
         segm = n.array([[[ 0, 0,  0], [ 1, 0, 0], [ 1, 0,-1], [ 1, 1,  1]],
                         [[ 1, 1,  0], [ 1, 0,-1], [ 0, 0,-1], [ 1, 1,  1]]])
 
     # Laue group : -3
     if Laue_class == '-3' and cell_choice=='rhombohedral':
-        print('Laue class : -3 (Rhom)', unit_cell)
+        logger.debug('Laue class : -3 (Rhom) %s'%unit_cell)
         if unit_cell[4]!=unit_cell[5]:
-            print('#############################################################')
-            print('# Are you using a hexagonal cell in a rhombohedral setting? #')
-            print('#############################################################')
+            logger.debug('#############################################################')
+            logger.debug('# Are you using a hexagonal cell in a rhombohedral setting? #')
+            logger.debug('#############################################################')
         segm = n.array([[[ 0, 0,  0], [ 1, 0, 0], [ 1, 0,-1], [ 1, 1, 1]],
                         [[ 1, 1,  0], [ 1, 0,-1], [ 0, 0,-1], [ 1, 1, 1]],
                         [[ 0,-1, -2], [ 1, 0, 0], [ 1, 0,-1], [-1,-1, -1]],
@@ -1240,7 +1242,7 @@ def genhkl_base(unit_cell, sysconditions, sintlmin, sintlmax, crystal_system='tr
                         [[ 1, 2,  0], [ 0, 1, 0], [ 1, 1, 0], [ 1, 1,  1]]])
 
     if segm is None:
-        print('No Laue class found')
+        logger.debug('No Laue class found')
         return False
 
     nref = 0
